@@ -7,7 +7,6 @@ use Illuminate\Http\Request;
 use Illuminate\Support\Facades\Config;
 
 use App\Classes\LDAP\Server;
-use App\Ldap\User;
 
 /**
  * This sets up our application session with any required values, ultimately for cache optimisation reasons
@@ -25,9 +24,6 @@ class ApplicationSession
 	{
 		Config::set('server',new Server);
 
-		view()->share('server', Config::get('server'));
-		view()->share('user', auth()->user() ?: new User);
-
 		return $next($request);
 	}
 }
\ No newline at end of file
