@@ -1,5 +1,5 @@
 <div class="row pt-2">
-	<div @class(['col-1','d-none'=>(! $edit) && (! ($detail ?? false))])></div>
+	<div @class(['col-1','d-none'=>(! $edit) && (! ($detail ?? FALSE))])></div>
 	<div class="col-10">
 		<attribute id="{{ $o->name }}">
 			{{ $slot }}
